#
# spec file for package python-respx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-respx
Version:        0.21.1
Release:        3.3
Summary:        Mock HTTPX with request patterns and response side effects
License:        BSD-3-Clause
URL:            https://github.com/lundberg/respx
Source0:        https://github.com/lundberg/respx/archive/refs/tags/%{version}.tar.gz#/respx-%{version}.tar.gz
# PATCH-FIX-UPSTREAM respx-pr267-httpx0.28.patch gh#lundberg/respx#267
Patch0:         respx-pr267-httpx0.28.patch
# PATCH-FIX-UPSTREAM respx-pr278-httpx0.28.patch gh#lundberg/respx#278
Patch1:         respx-pr278-httpx0.28.patch
BuildRequires:  %{python_module Flask}
# >= 0.28 for tests because of the Patches
BuildRequires:  %{python_module httpx >= 0.28}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module starlette}
BuildRequires:  %{python_module trio}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-httpx >= 0.21
BuildArch:      noarch
%python_subpackages

%description
Python library to mock httpx with request patterns and responses

%prep
%autosetup -p1 -n respx-%{version}
sed -i '/--cov/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -rfE

%files %{python_files}
%license LICENSE.md
%doc README.md
%{python_sitelib}/respx-%{version}.dist-info
%{python_sitelib}/respx

%changelog
* Thu Dec 12 2024 Ben Greiner <code@bnavigator.de>
- Add patches for httpx 0.28
  * respx-pr267-httpx0.28.patch gh#lundberg/respx#267
  * respx-pr278-httpx0.28.patch gh#lundberg/respx#278
* Wed May 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add sle15_python_module_pythons
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.21.1:
  * Fix `files` pattern not handling `str` and `BytesIO`
  * Add support for `None` values in `data` pattern
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.21.0:
  * Fix matching request data when files are provided
  * Add support for data\_\_contains lookup
  * Add `files` pattern to support matching on uploads
  * Add `SetCookie` utility for easier mocking of response cookie
    headers
  * Enhance documentation on iterable side effects
  * Enhance documentation on named routes and add tip about a
    catch-all route
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.20.2:
  * Better assertion output for `assert_all_called`
  * Support for quoted path pattern matching
  * Enable content\_\_contains pattern, thanks @rjprins
  * Added initial `CONTRIBUTING.md`, thanks @morenoh149
  * Docs about retrieving mocked calls, thanks
  * Docs about `Router.assert_all_called()`, thanks @BeyondEvil
    for input
- drop use-real-ipv6-address.patch (upstream)
* Fri Jun 16 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-real-ipv6-address.patch:
  * Use a real IPv6 address to avoid an address parsing exception
* Mon Jan 16 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.20.1
  * Support HTTPX 0.23.1, thanks @g-as for input (#223)
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.20.0
  Changed
  * Type Router.__getitem__ to not return optional routes, thanks @flaeppe (#216)
  * Change Call.response to raise instead of returning optional response (#217)
  * Change CallList.last to raise instead of return optional call (#217)
  * Type M() to not return optional pattern, by introducing a Noop pattern (#217)
  * Type Route.pattern to not be optional (#217)
  Fixed
  * Correct type hints for side effects (#217)
  Added
  * Runs mypy on both tests and respx (#217)
  * Added nox test session for python 3.11 (#217)
  * Added Call.has_response helper, now that .response raises (#217)
* Mon Aug 22 2022 Steve Kowalik <steven.kowalik@suse.com>
- Run pytest with --asyncio-mode=auto due to new release of
  pytest-asyncio.
* Tue Aug  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Initial package for 0.19.2
